Nl3

Struct Nl3 

pub struct Nl3 { /* private fields */ }
A configured nl3 client. Create one with Nl3::builder. Ports the instance returned by the create factory in index.js.

Implementations

Source

impl Nl3

pub fn builder() -> Nl3Builder

Start building a client.

pub fn parse(&self, text: &str) -> Result<Triple, ParseError>

Parse a phrase into a Triple. Ports lib/parse.js.

Errors

Returns ParseError::EmptyInput for empty/whitespace input, and ParseError::InvalidTriple when the phrase does not match the grammar in either direction.